<?php
/**
 * Implementiert die Seite, die das Gateway neustartet um eine Firmware zu installieren
 * @author Florian Kraatz <fk@beronet.com>
 * @author Miguel Palmer <mp@beronet.com>
 */

class UpdateTool {

	private	$_m = null,
					$_is_sbc_vm = '0';

	private $_isError = false,
					$_reasonResponse 	= array();

	private $_data 				= array(),
					$_parameters 	= array();

	/* [CONSTRUCTOR] */
	function __construct($m, $get = array(), $post = array(), $session = array()) {
		$this->_m = $m;

		$image_dir = "/tmp/images";
		if (!file_exists($image_dir)) {
			system("mkdir -p $image_dir");
		}

		require_once('/usr/fallback/beroConf.php');
		$bc = new beroConf('root'); 
		$this->_is_sbc_vm = ($bc->get('root', 'is-sbc-vm') == 1) ? 1 : 0;
		if ($this->_is_sbc_vm) {
			// set data
			$this->_parameters = require('/usr/local/www/berogui/modules/UpdateTool/updatetool_parameters_sbcvm.php');
			foreach ($this->_parameters['data'] as $key => $params) {
				$data = $bc->get('root', $key);
				$this->_data[$key] = strlen($data) == 0 ? $params['default'] : $data;
			}
		}
		else {
			$this->_parameters = require('/usr/local/www/berogui/modules/UpdateTool/updatetool_parameters.php');
		}

		// set error
		if (isset($get['error'])) {
			$this->_isError = true;
			$this->_reasonResponse = $get;
		}
	}

	/* [PUBLIC METHODS] */
	public function display() {
		$title = array(
			0 => 'UPDATE_TOOL_TITLE_DIS',
			1 => 'UPDATE_TOOL_SBCVM_TITLE_DIS',
		);
		$name = $title[$this->_is_sbc_vm];
		include('./includes/header.php');
		$ret .= "\n";

		$display_list = array(
			0 => '_displaySbc',
			1 => '_displaySbcVm',
		);
		$display = $display_list[$this->_is_sbc_vm];

		$ret .=	($this->_isError ? $this->_setError($this->_reasonResponse) : '')
					. "<div id='content' style='margin-top:45px;'>\n"
					. $this->$display("\t")
					. "</div>\n";
		return $ret;
	}

	/* [PRIVATE METHODS] */
	private function _buttonDownloadLogFile($tab = "") {
		$permlog = $this->_parameters['btns']['permlog'];
		if (!file_exists($permlog['file'])) {
			return '';
		}
		$dir_contents = scandir($permlog['file']);
		$file_count = 0;
		foreach ($dir_contents as $logfile) {
			if (($logfile == '.') || ($logfile == '..')) {
				continue;
			}
			$file_count++;
		}
		if ($file_count == 0) {
			return '';
		}
		$html =	"$tab<form method='POST'>\n"
					. "$tab\t<div class='text-center' style='margin-top:25px;'>\n"
					. "$tab\t\t<input type='button' class='btn btn-default' value='". constant($permlog['title']) ."'"
					.	"onclick='window.location.href=\"modules/UpdateTool/permlog.php\";' onmouseover='Tip(\"". constant($permlog['tooltip']) ."\");' onmouseout='UnTip();'/>\n"
					. "$tab\t</div>\n"
					. "$tab</form>\n";
		return $html;
	}

	private function _displaySbc($tab = "") {
		$msgs = $this->_parameters['msg'];
		$permlog = $this->_parameters['btns']['permlog'];
		$sbc_update = $this->_parameters['btns']['update'];

		//available FW version form FW list
		$html_fw = '';
		if (file_exists($sbc_update['file']) && $get_fw_list = file_get_contents($permlog['file'])) {
			if (preg_match("/Firmware ([0-9.]{1,5});appfs/", $get_fw_list, $fw_matched)) { 
				$html_fw =	"$tab<table class='table table-striped table-bordered' style='width:30% !important; margin:auto; text-align: center;'>\n"
									. "$tab\t<tr><th class='text-center'>". constant($msgs['available']) ."</th></tr>\n"
									. "$tab\t<tr><td>{$fw_matched[1]}</td></tr>\n"
									. "$tab</table>\n";
			}	
		}		
		ob_start();
		?>
		<script>
        	function checkupdate(option) {
          	if (option != "0") {
           		alert('<?php echo constant($msgs['alert']); ?>');
           		return false;
           	}
           	conf = confirm('<?php echo constant($msgs['confirm']); ?>');
						if (conf == false) {
            	return false;
            }
						else{
            	return true;
            }
        	}
    </script>
		<?php
		$html = ob_get_clean();
		$html .= $html_fw
					. "$tab<div class='text-center'>\n"
					. "$tab\t<form method='POST' action='./reboot.php' onsubmit='return checkupdate(\"". Helper::getActivateOption() ."\");'>\n"
					. "$tab\t\t<input type='hidden' name='action' value='reboot'>\n"
					. "$tab\t\t<input type='hidden' name='v' value='Yes'>\n"
					. "$tab\t\t<input type='hidden' name='module' value='fw_update'>\n"
					. "$tab\t\t<input type='submit' class='btn btn-default' name='submit' value='". constant($sbc_update['title']) ."'/>\n"
					. "$tab\t</form>\n"
					. $this->_buttonDownloadLogFile($tab)
					. "$tab</div>\n";
		return $html;
	}

	private function _displaySbcVm($tab = '') {
		require_once('./includes/Helper/HelperHtml.php');

		$html = "$tab<form method='POST' id='id_sbcvm_form' class='form-horizontal' action='./modules/UpdateTool/updatetool_submit.php'>\n";
		foreach ($this->_parameters['data'] as $key => $params) {
			$function = $params['display'];
			$html .= HelperHtml::$function($key, $this->_data[$key], $params, "$tab\t");
		}
		foreach ($this->_parameters['btns'] as $key => $params) {
			$function = $params['display'];
			$html .= HelperHtml::$function($key, $params['title'], $params, "$tab\t");
		}
		$html .= "$tab</form>\n";

		$message = $this->_parameters['msg'];
		ob_start();
		?>
		<script type="text/javascript" language="javascript">
			window.ajaxLoading = false;
			function doUpdate() {
				$('#update-info').html('<?php echo $waiting; ?>');
				$.ajax({
					cache: false,
					data: {
						'sbcvmupdate-reboot': $('#id_sbcvmupdate-reboot').is(':checked'),
					},
					error: function(request, stat, error) {
						$('#update-info').css('color', 'red');
						$('#update-info').html(error);
						document.getElementById("wait_div").style.display = "none";	
					},
					success: function(data) {
						document.getElementById("wait_div").style.display = "none";
						if (data == '1') {
							window.location.href = './reboot.php';
						}
						else {
							$('#update-info').css('color', 'green');
							$('#update-info').html('<?php echo constant($message['successful']); ?>');
						}
					},
					timeout: 60000,
					type: 'POST',
					url: "./modules/UpdateTool/updatetool_ajax.php",
				});
			}
			function manualUpdate(isActiveCalls, callback) {
				var message;
				var title = '<?php echo constant($message['act-call-title']); ?>';
				if (isActiveCalls == 0) {
					message = '<?php echo constant($message['act-call-confirm1']); ?>';
				}
				else {
					message = '<?php echo constant($message['act-call-confirm2']); ?>';
				}
				$("#dialog-confirm").dialog({
					autoOpen: false,
					modal: true
				});
				$('#dialog-confirm').dialog('option', 'title', title);	
				$("#dialogtext").html(message);
				$("#dialog-confirm").dialog("open");
				$("#dialog-confirm").dialog({
					buttons: {
						"Confirm": function () {
							$(this).dialog("close");
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
							document.getElementById("wait_div").style.display = "block";	
							callback();
						},
						"Cancel": function () {
							$(this).dialog("close");
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
						}
					}
				});
			}
			function showFields(isManual) {
				if (isManual) {
					$('#id_sbcvmupdate-update').show();
					$('#iddiv_sbcvmupdate-shownotif').hide();
					$('#id_sbcvmupdate-save').hide();
				}
				else {
					$('#id_sbcvmupdate-update').hide();
					$('#iddiv_sbcvmupdate-shownotif').show();
					$('#id_sbcvmupdate-save').show();
				}
			}
			$('#id_sbcvmupdate-mode').change(function() {
				showFields(this.value === 'manual');
			});
			$(document).ready(function() {
				showFields(<?php echo ($this->_data['sbcvmupdate-mode'] == 'manual' ? 'true' : 'false'); ?>);
				$('#id_sbcvm_form').submit(function (evt) {
					// save request -> submit
					if ($('#id_sbcvmupdate-save').is(':visible') == true) {
						return;
					}
					// manual update -> cancel submit and realize an AJAX request
					evt.preventDefault();
					if (window.ajaxLoading) {
						return;
					}
					else if (<?php echo Helper::getActivateOption(); ?> != 0) {
						alert('<?php echo constant($message['alert']); ?>');
						return;
					}
					window.ajaxLoading = true;
					$.ajax({
						cache: false,
						error: function(request, stat, error) {
							$('#update-info').css('color', 'red');
							$('#update-info').html(error);
							window.ajaxLoading = false;
							$('#id_sbcvmupdate-update').prop('disabled', false);
						},
						success: function(data) {
							manualUpdate(data, doUpdate);
						},
						timeout: 2000,
						url: "./misc/getTotalCalls.php",
					});
				});
			});
		</script>
		<?php
		return $html. ob_get_clean() ."\n";
	}

	private function _setError($reason) {
		switch ($reason['error']) {
		case 1:
			return Helper::displayErrorMessage($reason['request'], $reason['checkor'], $reason['key']);
		case 2:
		case 3:
			return "<div id='update-info' class='text-center' style='margin-top: 5px; color: red;'>"
				. constant($this->_parameters['msg']["error-{$reason['error']}"])
				. "</div>\n";
		default:
			return "";
		}
	}
}
?>
